use std::io::{Read, Write};

use anyhow::Context;
use clap::Parser;

#[derive(Parser)]
#[command(author, version, about, long_about = None)]
struct Command {
    #[arg()]
    substr: String,
}

#[tokio::main]
async fn main() -> anyhow::Result<()> {
    dotenv::dotenv().ok();
    tracing_subscriber::fmt::init();

    let cli = Command::parse();
    tracing::debug!("Starting cli");

    let mut input = String::new();
    std::io::stdin()
        .read_to_string(&mut input)
        .context("failed to read from stdin")?;

    let mut stdout = std::io::stdout();
    if let Some((before, _)) = input.split_once(&cli.substr) {
        stdout.write_all(before.as_bytes())?;
    } else {
        stdout.write_all(input.as_bytes())?;
    }
    stdout.flush()?;

    if input.is_empty() {
        tracing::info!("no content to put in clipboard");
        return Ok(());
    }

    Ok(())
}
